@@ -1,14 +1,11 @@
 ##----------------------------------------------------------------------------
 ## Stripe API - ~/lib/Net/API/Stripe/Product/PackageDimension.pm
-## Version 0.1
-## Copyright(c) 2019-2020 DEGUEST Pte. Ltd.
-## Author: Jacques Deguest <jack@deguest.jp>
+## Version v0.100.0
+## Copyright(c) 2019 DEGUEST Pte. Ltd.
+## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
 ## Created 2019/11/02
-## Modified 2019/11/02
-## All rights reserved
+## Modified 2020/05/15
 ## 
-## This program is free software; you can redistribute  it  and/or  modify  it
-## under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
 package Net::API::Stripe::Product::PackageDimension;
 BEGIN
@@ -16,7 +13,7 @@ BEGIN
     use strict;
     use parent qw( Net::API::Stripe::Generic );
     use Net::API::Stripe::Number;
-    our( $VERSION ) = '0.1';
+    our( $VERSION ) = 'v0.100.0';
 };
 
 sub init
@@ -135,7 +132,7 @@ Net::API::Stripe::Product::PackageDimension - A Stripe Product Package Dimension
 
 =head1 VERSION
 
-    0.1
+    v0.100.0
 
 =head1 DESCRIPTION
 
